@@ -1,10 +1,9 @@
-use crate::utils::{get_dvm_root, get_exe_path};
-use crate::version::get_current_version;
-use std::fs;
-use std::process::exit;
-
+use crate::utils::{deno_bin_path, dvm_root};
+use crate::version::current_version;
 use anyhow::Result;
 use semver_parser::version::parse as semver_parse;
+use std::fs;
+use std::process::exit;
 
 pub fn exec(version: Option<String>) -> Result<()> {
   let target_version = match version {
@@ -17,21 +16,21 @@ pub fn exec(version: Option<String>) -> Result<()> {
     },
     None => unimplemented!(),
   };
-  let target_exe_path = get_exe_path(&target_version);
+  let target_exe_path = deno_bin_path(&target_version);
 
   if !target_exe_path.exists() {
     eprintln!("deno v{} is not installed.", target_version);
     exit(1)
   }
 
-  let current_version = get_current_version().unwrap();
+  let current_version = current_version().unwrap();
 
   if current_version == target_version.to_string() {
     println!("Failed: deno v{} is in use.", target_version);
     exit(1);
   }
 
-  let dvm_dir = get_dvm_root().join(format!("{}", target_version));
+  let dvm_dir = dvm_root().join(format!("{}", target_version));
 
   fs::remove_dir_all(&dvm_dir).unwrap();
   println!("deno v{} removed.", target_version);
